@@ -203,4 +203,23 @@ class StudentDormitoryRoomSettleHistory(Base):
         )
 
     def __str__(self):
-        return str(self.student)
\ No newline at end of file
+        return str(self.student)
+
+
+class DormitoryStudentAccess(Base):
+    """
+    Модель "Доступ студента к общежитию"
+    """
+    __tablename__ = 'univer_dormitory_student_access'
+
+    student_id = Column(ForeignKey('univer_students.students_id'))
+    student = relationship('Student')  # Студент
+    status = Column('access_status', Integer)  # Статус доступа
+    year = Column(Integer)  # Год
+
+    def __repr__(self):
+        return '<DormitoryStudentAccess (student_id={}, status={}, year={})>'.format(
+            self.student_id,
+            self.status,
+            self.year
+        )
\ No newline at end of file
